# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`foreman_scap_client`](#foreman_scap_client): Configures foreman_scap_client and sets cron tasks to run it

#### Private Classes

* `foreman_scap_client::params`: Params class for parent foreman_scap_client

## Classes

### <a name="foreman_scap_client"></a>`foreman_scap_client`

Configures foreman_scap_client and sets cron tasks to run it

#### Examples

##### Run a weekly SCAP audit

```puppet
class { foreman_scap_client:
  server           => 'proxy.example.com',
  port             => '8443',
  foreman_repo_rel => '1.24',
  policies         => [{
    "id"                      => 1,
    "hour"                    => "12",
    "minute"                  => "1",
    "month"                   => "*",
    "monthday"                => "*",
    "weekday"                 => "1",
    "profile_id"              => '',
    "content_path"            => '/usr/share/xml/scap/ssg/fedora/ssg-fedora-ds.xml',
    "download_path"           => '/compliance/policies/1/content',
    "tailoring_path"          => '/var/lib/openacap/ssg-fedora-ds-tailored.xml',
    "tailoring_download_path" => "/compliance/policies/1/tailoring"
  }]
}
```

#### Parameters

The following parameters are available in the `foreman_scap_client` class:

* [`ensure`](#-foreman_scap_client--ensure)
* [`install_options`](#-foreman_scap_client--install_options)
* [`server`](#-foreman_scap_client--server)
* [`port`](#-foreman_scap_client--port)
* [`ca_file`](#-foreman_scap_client--ca_file)
* [`host_certificate`](#-foreman_scap_client--host_certificate)
* [`host_private_key`](#-foreman_scap_client--host_private_key)
* [`package_name`](#-foreman_scap_client--package_name)
* [`package_provider`](#-foreman_scap_client--package_provider)
* [`foreman_repo_rel`](#-foreman_scap_client--foreman_repo_rel)
* [`foreman_repo_key`](#-foreman_scap_client--foreman_repo_key)
* [`foreman_repo_src`](#-foreman_scap_client--foreman_repo_src)
* [`foreman_repo_gpg_chk`](#-foreman_scap_client--foreman_repo_gpg_chk)
* [`policies`](#-foreman_scap_client--policies)
* [`cron_template`](#-foreman_scap_client--cron_template)
* [`cron_splay`](#-foreman_scap_client--cron_splay)
* [`http_proxy_server`](#-foreman_scap_client--http_proxy_server)
* [`http_proxy_port`](#-foreman_scap_client--http_proxy_port)
* [`fetch_remote_resources`](#-foreman_scap_client--fetch_remote_resources)
* [`timeout`](#-foreman_scap_client--timeout)

##### <a name="-foreman_scap_client--ensure"></a>`ensure`

Data type: `String`

Passed to the rubygem-foreman_scap_client package.

Default value: `'present'`

##### <a name="-foreman_scap_client--install_options"></a>`install_options`

Data type: `Optional[String]`

Passed to the rubygem-foreman_scap_client package.

Default value: `undef`

##### <a name="-foreman_scap_client--server"></a>`server`

Data type: `Stdlib::Host`

foreman proxy url where arf reports should be sent

##### <a name="-foreman_scap_client--port"></a>`port`

Data type: `Stdlib::Port`

port of foreman proxy that is used as $server

##### <a name="-foreman_scap_client--ca_file"></a>`ca_file`

Data type: `Stdlib::Absolutepath`

path to file of certification authority that issued client's certificate
May be overriden if the rh_certificate_repo_ca_file fact is found

Default value: `$foreman_scap_client::params::ca_file`

##### <a name="-foreman_scap_client--host_certificate"></a>`host_certificate`

Data type: `Stdlib::Absolutepath`

path to host certificate, usually puppet agent certificate
May be overriden if the rh_certificate_consumer_host_cert fact is found

Default value: `$foreman_scap_client::params::host_certificate`

##### <a name="-foreman_scap_client--host_private_key"></a>`host_private_key`

Data type: `Stdlib::Absolutepath`

path to host private key, usually puppet agent private key
May be overriden if the rh_certificate_consumer_host_key fact is found

Default value: `$foreman_scap_client::params::host_private_key`

##### <a name="-foreman_scap_client--package_name"></a>`package_name`

Data type: `String`

Package name for Ruby foreman_scap_client package

Default value: `'rubygem-foreman_scap_client'`

##### <a name="-foreman_scap_client--package_provider"></a>`package_provider`

Data type: `Optional[String]`

provider for the package, defaults to yum but can be set to gem, or any other valid
puppet package provider

Default value: `undef`

##### <a name="-foreman_scap_client--foreman_repo_rel"></a>`foreman_repo_rel`

Data type: `Optional[String]`

add / manage foreman-plugins yum repo and set to release version. Eg  '1.14'

Default value: `undef`

##### <a name="-foreman_scap_client--foreman_repo_key"></a>`foreman_repo_key`

Data type: `String`

RPM Key source file for foreman-plugins repo. Note: Currently, packages are not signed.
Unless set to an alternative file source, URL will be used.

Default value: `'https://yum.theforeman.org/RPM-GPG-KEY-foreman'`

##### <a name="-foreman_scap_client--foreman_repo_src"></a>`foreman_repo_src`

Data type: `Optional[String]`

Alternative baseurl for The Foreman plugins repository

Default value: `undef`

##### <a name="-foreman_scap_client--foreman_repo_gpg_chk"></a>`foreman_repo_gpg_chk`

Data type: `Boolean`

Enable / disable GPG checks. Directly passed to Yumrepo resource

Default value: `false`

##### <a name="-foreman_scap_client--policies"></a>`policies`

Data type: `Array`

Array of policies that should be configured, each member represent
one policy in form of hash
Policy hash must have following structure

{ "id" => 1, "hour" => "*", "minute" => "*", "month" => "*",
  "monthday" => "*", "weekday" => "*", "profile_id" => '',
  "content_path" => '/usr/share/...',
  "tailoring_path" => '/var/lib...'
}

note that profile_id may be empty (for default profile)
id is number representing id of policy in foreman
content_path is path to DS file that contains profile

if it's not array, it's automatically converted to it, so you can
even specify just one policy as a hash

##### <a name="-foreman_scap_client--cron_template"></a>`cron_template`

Data type: `String`

Path to cron template

Default value: `'foreman_scap_client/cron.erb'`

##### <a name="-foreman_scap_client--cron_splay"></a>`cron_splay`

Data type: `Integer[0]`

Upper limit for splay time when sending reports to proxy

Default value: `600`

##### <a name="-foreman_scap_client--http_proxy_server"></a>`http_proxy_server`

Data type: `Optional[Stdlib::Host]`

HTTP proxy server

Default value: `undef`

##### <a name="-foreman_scap_client--http_proxy_port"></a>`http_proxy_port`

Data type: `Optional[Stdlib::Port]`

HTTP proxy port

Default value: `undef`

##### <a name="-foreman_scap_client--fetch_remote_resources"></a>`fetch_remote_resources`

Data type: `Boolean`

Whether client should fetch referenced resources that are remote

Default value: `false`

##### <a name="-foreman_scap_client--timeout"></a>`timeout`

Data type: `Integer[0]`

Timeout when sending reports to proxy

Default value: `60`

